@@ -27,32 +27,31 @@ public:
     	class DottedPairProxy : public GenericProxy<DottedPairProxy> {
 	public:
 		DottedPairProxy( CLASS& v, int index_ ): node(R_NilValue){
-            if( index_ >= v.length() ) throw index_out_of_bounds() ;
+            if( index_ >= v.length() ) {
+                const char* fmt = "Dotted Pair index is out of bounds: "
+                                  "[index=%i; extent=%i].";
+                throw index_out_of_bounds(fmt, index_, v.length());
+            }
+
             SEXP x = v ; /* implicit conversion */
             for( int i = 0; i<index_; i++, x = CDR(x) ) ;
             node = x ;
         }
 
-		DottedPairProxy& operator=(const DottedPairProxy& rhs){
+		DottedPairProxy& operator=(const DottedPairProxy& rhs) {
 		    return set(rhs.get());
 		}
-		DottedPairProxy& operator=(SEXP rhs){
+		DottedPairProxy& operator=(SEXP rhs) {
 		    return set(rhs) ;
 		}
 
 		template <typename T>
-		DottedPairProxy& operator=(const T& rhs) {
-      return set( wrap(rhs) );
-		}
+		DottedPairProxy& operator=(const T& rhs);
 
 		template <typename T>
-		DottedPairProxy& operator=(const traits::named_object<T>& rhs) {
-      return set( wrap(rhs.object), rhs.name ) ;
-		}
+		DottedPairProxy& operator=(const traits::named_object<T>& rhs);
 
-		template <typename T> operator T() const {
-      return as<T>( get() );
-		}
+		template <typename T> operator T() const;
 
 		inline SEXP get() const {
 		    return CAR(node);
@@ -78,15 +77,18 @@ public:
 	class const_DottedPairProxy : public GenericProxy<const_DottedPairProxy>{
 	public:
 		const_DottedPairProxy( const CLASS& v, int index_ ): node(R_NilValue){
-            if( index_ >= v.length() ) throw index_out_of_bounds() ;
+            if( index_ >= v.length() )  {
+                const char* fmt = "Dotted Pair index is out of bounds: "
+                                  "[index=%i; extent=%i].";
+                throw index_out_of_bounds(fmt, index_, v.length());
+            }
+
             SEXP x = v ; /* implicit conversion */
             for( int i = 0; i<index_; i++, x = CDR(x) ) ;
             node = x ;
         }
 
-		template <typename T> operator T() const {
-      return as<T>( get() );
-		}
+		template <typename T> operator T() const;
 
 		inline SEXP get() const {
 		    return CAR(node);
